Re-exports
pub use reader::*;
Modules
Structs
- BigEndian
- Big-endian, or most significant bits first
- Byte
Reader - For reading aligned bytes from a stream of bytes in a given endianness.
- Little
Endian - Little-endian, or least significant bits first
Traits
- Byte
Read - A trait for anything that can read aligned values from an input stream